# Import the output to reproduce Figures 2 and 3 in the paper.
load("iso_outseq_shift14.RData")

library(ggplot2)

My_Theme = theme(
  axis.title.x = element_text(size = 14),
  axis.text.x = element_text(size = 12),
  axis.title.y = element_text(size = 14),
  axis.text.y = element_text(size = 12),
  plot.title = element_text(hjust = 0.5, size = 14),
  legend.title = element_text(size=14),
  legend.text = element_text(size=12),
  panel.grid.major.x = element_blank(),
  panel.grid.minor.x = element_blank())



###############
###  SE
##############

se <- c(as.vector(SE_PG), as.vector(SE_MM), as.vector(SE_MLE))/n # get MSE
outliers <- rep(rep(outSeq, each=numRep), 3)
Method <- rep(c("PG", "MM", "LS"), each =numRep*numOut)
Method <- factor(Method, levels=c("PG", "MM", "LS"))
outliers <- as.factor(outliers)
data <- data.frame(Method, outliers, se)


ggplot(data, aes(x=outliers, y=log10(se), fill=Method)) + theme_bw()+
  labs(
    y=expression(paste(Log[10], '(MSE)')), x="Number of outliers")+
  geom_boxplot()+scale_fill_brewer(palette="Dark2")+
  theme(
    axis.title.x = element_text(size = 14),
    axis.text.x = element_text(size = 12),
    axis.title.y = element_text(size = 14),
    axis.text.y = element_text(size = 12),
    legend.title=element_text(size=14), 
    legend.text=element_text(size=12)
  )


###############
###  Time
##############

tm <- c(as.vector(TM_PG), as.vector(TM_MM), as.vector(TM_MLE))
outliers <- rep(rep(outSeq, each=numRep), 3)
Method <- rep(c( "PG", "MM", "LS"), each =numRep*numOut)
Method <- factor(Method, levels=c( "PG", "MM", "LS"))
outliers <- as.factor(outliers)
data <- data.frame(Method, outliers, tm)


ggplot(data, aes(x=outliers, y=tm, fill=Method)) + theme_bw() +
  labs(
    y="Time (seconds)", x="Number of outliers")+
  geom_boxplot()+scale_fill_brewer(palette="Dark2")+
  theme(
    axis.title.x = element_text(size = 14),
    axis.text.x = element_text(size = 12),
    axis.title.y = element_text(size = 14),
    axis.text.y = element_text(size = 12),
    legend.title=element_text(size=14), 
    legend.text=element_text(size=12)
  ) +
  scale_y_continuous(trans = scales::log_trans(),
                     breaks = c(0.01, 0.05, 0.25, 1, 5, 15, 50)
  )


###############
###  Iteration of BCD
##############
iters <- c(as.vector(IT_PG), as.vector(IT_MM))
outliers <- rep(rep(outSeq, each=numRep), 2)
Method <- rep(c("PG", "MM"), each =numRep*numOut)
Method <- factor(Method, levels = c( "PG", "MM"))
outliers <- as.factor(outliers)
data <- data.frame(Method, outliers, iters)


p1 <- ggplot(data, aes(x=outliers, y=iters, fill=Method)) + theme_bw() +
  labs(
    y="Number of iterations (BCD)", x="Number of outliers")+
  geom_boxplot(width=0.5)+scale_fill_brewer(palette="Dark2")+
  theme(
    axis.title.x = element_text(size = 14),
    axis.text.x = element_text(size = 12),
    axis.title.y = element_text(size = 14),
    axis.text.y = element_text(size = 12),
    legend.title=element_text(size=14), 
    legend.text=element_text(size=12)
  )+
  scale_y_continuous(trans = scales::log_trans(),
                     breaks = c(1, 5, 10, 50, 100, 500)
                     )


###############
###  Iteration for updating beta
##############
iters_beta <- c(as.vector(IT_beta_PG), as.vector(IT_beta_MM))
outliers <- rep(rep(outSeq, each=numRep), 2)
Method <- rep(c("PG", "MM"), each =numRep*numOut)
Method <- factor(Method, levels = c( "PG", "MM"))
outliers <- as.factor(outliers)
data <- data.frame(Method, outliers, iters_beta)


p2 <- ggplot(data, aes(x=outliers, y=iters_beta, fill=Method)) + theme_bw() +
  labs(
    y=expression(paste('Number of iterations (', beta, ")")), x="Number of outliers")+
  geom_boxplot(width=0.5)+scale_fill_brewer(palette="Dark2")+
  theme(
    axis.title.x = element_text(size = 14),
    axis.text.x = element_text(size = 12),
    axis.title.y = element_text(size = 14),
    axis.text.y = element_text(size = 12),
    legend.title=element_text(size=14), 
    legend.text=element_text(size=12)
  )




###############
###  Iteration for updating tau
##############
iters_tau <- c(as.vector(IT_tau_PG), as.vector(IT_tau_MM))
outliers <- rep(rep(outSeq, each=numRep), 2)
Method <- rep(c("PG", "MM"), each =numRep*numOut)
Method <- factor(Method, levels = c( "PG", "MM"))
outliers <- as.factor(outliers)
data <- data.frame(Method, outliers, iters_tau)


p3 <- ggplot(data, aes(x=outliers, y=iters_tau, fill=Method)) +theme_bw() +
  labs(
    y=expression(paste('Number of iterations (', tau, ")")), x="Number of outliers")+
  geom_boxplot(width=0.5)+scale_fill_brewer(palette="Dark2")+
  theme(
    axis.title.x = element_text(size = 14),
    axis.text.x = element_text(size = 12),
    axis.title.y = element_text(size = 14),
    axis.text.y = element_text(size = 12),
    legend.title=element_text(size=14), 
    legend.text=element_text(size=12)
  )+
  scale_y_continuous(trans = scales::log_trans(),
                     breaks = c(1, 5, 10, 25, 50, 100)
  )



library(cowplot)
library(ggpubr)
ggarrange(plot_grid(p1 + theme(legend.position="none"),
                    p2 + theme(legend.position="none"),
                    p3 + theme(legend.position="right"), 
                    ncol=3,rel_widths = c(1,1, 1.2)))



