# Please uncompress the zip file and set working directory to the folder containing the code by
# setwd("~/L2E-code")   # suppose the folder name is unchanged as L2E-code

# After setting working directory
source("update_beta_isotonic.R")
source("update_beta_MM_isotonic.R")
source("update_tau_R.R")
source("update_eta_bktk.R")
source("objectives.R")
source("l2e_regression_isotonic.R")
source("l2e_regression_isotonic_MM.R")


# Import the required packages
library(Iso)
library(isotone)

##########################
set.seed(12345)
n <- 1000
tau <- 1
x <- seq(-2.5, 2.5,length.out=n)
f <- x^3


outSeq<- c(50, 100, 200)
numOut <- length(outSeq)
numRep <- 5  ##### !!! PLEASE reset nuRep=100 if you want to reproduce the whole output file. But that takes ~40 miniutes.. 
SE_PG <- matrix(NA, nrow = numRep, ncol = numOut)
SE_MM <- matrix(NA, nrow = numRep, ncol = numOut)
SE_MLE <- matrix(NA, nrow = numRep, ncol = numOut)

TM_PG <- matrix(NA, nrow = numRep, ncol = numOut)
TM_MM <- matrix(NA, nrow = numRep, ncol = numOut)
TM_MLE <- matrix(NA, nrow = numRep, ncol = numOut)

IT_PG <- matrix(NA, nrow = numRep, ncol = numOut)
IT_MM <- matrix(NA, nrow = numRep, ncol = numOut)

IT_beta_PG <- matrix(NA, nrow = numRep, ncol = numOut)
IT_beta_MM <- matrix(NA, nrow = numRep, ncol = numOut)

IT_tau_PG <- matrix(NA, nrow = numRep, ncol = numOut)
IT_tau_MM <- matrix(NA, nrow = numRep, ncol = numOut)


obj_PG <- matrix(NA, nrow = numRep, ncol = numOut)
obj_MM <- matrix(NA, nrow = numRep, ncol = numOut)

tau_PG <- matrix(NA, nrow = numRep, ncol = numOut)
tau_MM <- matrix(NA, nrow = numRep, ncol = numOut)



Beta_PG <- list()
Beta_MM <- list()
Beta_MLE <- list()

for (k in 1:numOut) {
  
  print(k)
  
  beta_PG <- matrix(NA, n, numRep)
  beta_MM <- matrix(NA, n, numRep)
  beta_MLE <- matrix(NA, n, numRep)
  
  for (r in 1:numRep) {
    
    set.seed(2020+r)
    # generate y
    y <- f + rnorm(n)
    
    ## Contaminated
    ix <- 1:outSeq[k]
    y[250 + ix] <-  y[250 + ix] +14

    tau <- 1/mad(y)
    b <- y
    ############# PG ##############
    ptm <- proc.time()
    sol_PG <- l2e_regression_isotonic(y,b,tau=tau, max_iter = 1e3)
    t_PG <- proc.time()-ptm
    TM_PG[r, k] <-  t_PG[[3]]
    IT_PG[r, k] <- sol_PG$iter
    IT_beta_PG[r, k] <- mean(sol_PG$iter_beta)
    IT_tau_PG[r, k] <- mean(sol_PG$iter_tau)
    
    beta_PG[, r] <- sol_PG$beta
    SE_PG[r, k] <- norm(sol_PG$beta - f, "2")^2
    
    tau_PG[r, k] <- sol_PG$tau
    r_PG <- y - sol_PG$beta
    obj_PG[r, k] <- objective_tau(tau = sol_PG$tau, r = r_PG)
    
    
    ############# MM ##############
    ptm <- proc.time()
    sol_MM <- l2e_regression_isotonic_MM(y,b,tau, max_iter = 1e3)
    t_MM <- proc.time()-ptm
    TM_MM[r, k] <-  t_MM[[3]]
    IT_MM[r, k] <- sol_MM$iter
    IT_beta_MM[r, k] <- mean(sol_MM$iter_beta)
    IT_tau_MM[r, k] <- mean(sol_MM$iter_eta)
    
    beta_MM[, r] <- sol_MM$beta
    SE_MM[r, k] <- norm(sol_MM$beta - f, "2")^2
    
    tau_MM[r, k] <- sol_MM$tau
    r_MM <- y - sol_MM$beta
    obj_MM[r, k] <- objective_tau(tau = sol_MM$tau, r = r_MM)
    
    
    
    ############# MLE ##############
    ptm <- proc.time()
    iso <- gpava(1:n,y)
    t_MLE <- proc.time()-ptm
    TM_MLE[r, k] <-  t_MLE[[3]]
    
    beta_MLE[, r] <- iso$x
    SE_MLE[r, k] <- norm(iso$x - f, "2")^2
    
  }
  
  Beta_PG[[k]] <- beta_PG
  Beta_MM[[k]] <- beta_MM
  Beta_MLE[[k]] <- beta_MLE
}



save.image(file = "iso_outseq_shift14.RData")
